import PageContent from '@/components/PageContent';
import PageTitle from '@/components/PageTitle';
import {
  MandateChildType,
  MandateDetailType,
  PropsType,
  UserType,
  WorkOrderType,
} from '@/pages/TaskManage/Detail/detail.types';
import {
  MandateClass,
  MandateStatus,
  MandateType,
  OrderStatus,
  OrderType,
} from '@/pages/TaskManage/constent';
import {
  dispatchOrder,
  getMandateChildList,
  getMandateDetail,
  ignoreTask,
  setTaskAutomation,
} from '@/services/TaskManage';
import { connect, useLocation, useRequest } from '@umijs/max';
import React, { useEffect, useState } from 'react';

const TaskDetail: React.FC<PropsType> = (props) => {
  const { userList, dispatch } = props;
  const md5 = require('md5');
  const location = useLocation();
  const queryParams = new URLSearchParams(location.search);
  const project_id = Number(queryParams.get('project_id'));
  const mandate_id = Number(queryParams.get('mandate_id'));

  const [mandateDetail, setMandateDetail] = useState<MandateDetailType>();
  const [handledWorkOrders, setHandledWorkOrders] = useState<WorkOrderType[]>(
    [],
  );
  const [subMandateList, setSubMandateList] = useState<MandateChildType[]>([]);

  const { run: getDetail, refresh: refreshDetail } = useRequest(
    getMandateDetail,
    {
      defaultParams: [
        {
          project_id,
          mandate_id,
        },
      ],
      formatResult: (result) => {
        const mandate: MandateDetailType = {
          ...result.data,
          Status: MandateStatus.find((item) => item.value === result.data.Status),
          MandateClass: MandateClass.find(
            (item) => item.value === result.data.MandateClass,
          ),
          MandateType: MandateType.find(
            (item) => item.value === result.data.MandateType,
          ),
        };
        const workOrderList: WorkOrderType[] = result.data.Records.map(
          (record: WorkOrderType) => {
            return {
              ...record,
              Status: OrderStatus.find(
                (item) => item.value === record.Status,
              ),
              RecordType: OrderType.find(
                (item) => item.value === record.RecordType,
              ),
              Responsible: userList.find(
                (item: UserType) => item.ID === record.Responsible,
              ),
            };
          },
        );
        setMandateDetail(mandate);
        setHandledWorkOrders(workOrderList);
      },
    },
  );

  const {
    run: getMandateChild,
    loading,
    refresh: refreshMandateChild,
  } = useRequest(getMandateChildList, {
    defaultParams: [
      {
        mandateId: mandate_id,
      },
    ],
    formatResult: (result) => {
      setSubMandateList(result.data);
    },
  });

  const { run: setAuto } = useRequest(setTaskAutomation, {
    manual: true,
    onSuccess: () => {
      refreshDetail();
      refreshMandateChild();
    },
  });

  const { run: runIgnoreTask } = useRequest(ignoreTask, {
    manual: true,
    onSuccess: () => {
      refreshDetail();
      refreshMandateChild();
    },
  });

  const { run: runDispatch } = useRequest(dispatchOrder, {
    manual: true,
    onSuccess: () => {
      refreshDetail();
      refreshMandateChild();
    },
  });

  useEffect(() => {
    if (userList.length === 0) {
      dispatch({
        type: 'taskUser/fetchUserList',
        payload: { project_id },
      });
    }
  }, []);

  return (
    <PageContent>
      <PageTitle returnable>任务详情</PageTitle>

    </PageContent>
  );
};

export default connect(({ taskUser }: any): { userList: UserType[] } => {
  return {
    userList: taskUser.userList,
  };
})(TaskDetail);
