import PageContent from '@/components/PageContent';
import PageTitle from '@/components/PageTitle';
import {
  MandateClass,
  MandateStatus,
  MandateType,
} from '@/pages/TaskManage/constent';
import styles from '@/pages/TaskManage/index.less';
import { PropTypes, mandateType } from '@/pages/TaskManage/index.types';
import { getMandateList } from '@/services/TaskManage';
import { RightOutlined } from '@ant-design/icons';
import { useParams, useRequest } from '@umijs/max';
import { List, Spin } from 'antd';
import React, { useEffect, useState } from 'react';
import { useNavigate } from 'umi';

const TaskManage: React.FC<PropTypes> = (props) => {
  const { projectID } = useParams();
  console.log(projectID);
  const project_id = Number(projectID === '' ? '0' : projectID);

  const navigate = useNavigate();

  const [pagination, setPagination] = useState({
    total: 0,
    pageSize: 5,
    current: 1,
  });
  const [mandateList, setMandateList] = useState<mandateType[]>([]);

  const {
    run: runGetMandateList,
    loading,
    refresh: refreshMandateList,
  } = useRequest(getMandateList, {
    defaultParams: [
      {
        project_id,
        pageSize: pagination.pageSize,
        currentPage: pagination.current,
      },
    ],
    onSuccess: () => {},
    formatResult: (result) => {
      const mandates = result.data.list;
      mandates.forEach((mandate: mandateType) => {
        mandate.Status =
          MandateStatus.find((status) => status.value === mandate.Status) || 0;
        mandate.MandateClass =
          MandateClass.find(
            (classItem) => classItem.value === mandate.MandateClass,
          ) || 0;
        mandate.MandateType =
          MandateType.find((type) => type.value === mandate.MandateType) || 0;
      });
      setMandateList(result.data.list);
      setPagination(result.data.pagination);
    },
  });

  const goToDetail = (item: mandateType) => {
    navigate(
      `/task-manage/detail?project_id=${project_id}&mandate_id=${item.Id}`,
    );
  };

  const onPageChange = (page: number, pageSize: number) => {
    runGetMandateList({ project_id, currentPage: page, pageSize });
  };

  useEffect(() => {
    const bodyStyle = document.body.style.background;
    document.body.style.background = 'none';
    return () => {
      document.body.style.background = bodyStyle;
    };
  }, []);

  const makeList = (item: mandateType, index: number) => {
    return (
      <List.Item
        className={styles.listItem}
        onClick={() => {
          goToDetail(item);
        }}
      >
        <List.Item.Meta
          title={
            typeof item.MandateType === 'number' ? '' : item.MandateType.label
          }
          description={item.Detail}
        />
        <div className={styles.itemCount}>
          <div className={styles.countNumber}>10</div>
          <div>任务数量</div>
        </div>
        <RightOutlined />
      </List.Item>
    );
  };

  return (
    <PageContent>
      <PageTitle>任务管理</PageTitle>
      <Spin spinning={loading}>
        <List
          className={styles.taskList}
          bordered
          itemLayout="horizontal"
          dataSource={mandateList}
          renderItem={makeList}
          pagination={
            mandateList.length
              ? {
                  position: 'bottom',
                  align: 'end',
                  simple: true,
                  showSizeChanger: false,
                  onChange: onPageChange,
                  ...pagination,
                }
              : false
          }
        />
      </Spin>
    </PageContent>
  );
};

export default TaskManage;
